@@ -1,11 +1,9 @@
-# @(#)Ident: Unexpected.pm 2013-08-28 22:42 pjf ;
-
 package Unexpected;
 
 use 5.010001;
 use namespace::sweep;
-use overload '""' => 'as_string', fallback => 1;
-use version; our $VERSION = qv( sprintf '0.22.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use overload '""' => sub { $_[ 0 ]->as_string }, fallback => 1;
+use version; our $VERSION = qv( sprintf '0.23.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Scalar::Util qw( blessed );
@@ -72,7 +70,7 @@ Unexpected - Exception class composed from traits
 
 =head1 Version
 
-This documents version v0.22.$Rev: 1 $ of L<Unexpected>
+This documents version v0.23.$Rev: 1 $ of L<Unexpected>
 
 =head1 Description
 
